stalker.core.models.Type
========================

.. inheritance-diagram::
     stalker.core.models.Type
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Type
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Type.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Type.code
      ~Type.created_by
      ~Type.date_created
      ~Type.date_updated
      ~Type.description
      ~Type.name
      ~Type.nice_name
      ~Type.notes
      ~Type.tags
      ~Type.target_entity_type
      ~Type.type
      ~Type.updated_by
   
   